@@ -18,7 +18,7 @@ from typing import Any, Dict, Mapping, Type
 from botocore.client import BaseClient, ClientMeta
 
 from .literals import AlternateContactTypeType
-from .type_defs import GetAlternateContactResponseTypeDef
+from .type_defs import EmptyResponseMetadataTypeDef, GetAlternateContactResponseTypeDef
 
 __all__ = ("AccountClient",)
 
@@ -67,7 +67,7 @@ class AccountClient(BaseClient):
 
     def delete_alternate_contact(
         self, *, AlternateContactType: AlternateContactTypeType, AccountId: str = ...
-    ) -> None:
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Deletes the specified alternate contact from an Amazon Web Services account.
 
@@ -109,7 +109,7 @@ class AccountClient(BaseClient):
         PhoneNumber: str,
         Title: str,
         AccountId: str = ...
-    ) -> None:
+    ) -> EmptyResponseMetadataTypeDef:
         """
         Modifies the specified alternate contact attached to an Amazon Web Services
         account.
