@@ -25,10 +25,11 @@ else:
 __all__ = (
     "AlternateContactTypeDef",
     "DeleteAlternateContactRequestRequestTypeDef",
-    "GetAlternateContactRequestRequestTypeDef",
-    "GetAlternateContactResponseTypeDef",
-    "PutAlternateContactRequestRequestTypeDef",
     "ResponseMetadataTypeDef",
+    "GetAlternateContactRequestRequestTypeDef",
+    "PutAlternateContactRequestRequestTypeDef",
+    "EmptyResponseMetadataTypeDef",
+    "GetAlternateContactResponseTypeDef",
 )
 
 AlternateContactTypeDef = TypedDict(
@@ -65,6 +66,17 @@ class DeleteAlternateContactRequestRequestTypeDef(
     pass
 
 
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
+    {
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, str],
+        "RetryAttempts": int,
+    },
+)
+
 _RequiredGetAlternateContactRequestRequestTypeDef = TypedDict(
     "_RequiredGetAlternateContactRequestRequestTypeDef",
     {
@@ -87,14 +99,6 @@ class GetAlternateContactRequestRequestTypeDef(
     pass
 
 
-GetAlternateContactResponseTypeDef = TypedDict(
-    "GetAlternateContactResponseTypeDef",
-    {
-        "AlternateContact": "AlternateContactTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 _RequiredPutAlternateContactRequestRequestTypeDef = TypedDict(
     "_RequiredPutAlternateContactRequestRequestTypeDef",
     {
@@ -121,13 +125,17 @@ class PutAlternateContactRequestRequestTypeDef(
     pass
 
 
-ResponseMetadataTypeDef = TypedDict(
-    "ResponseMetadataTypeDef",
+EmptyResponseMetadataTypeDef = TypedDict(
+    "EmptyResponseMetadataTypeDef",
     {
-        "RequestId": str,
-        "HostId": str,
-        "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, str],
-        "RetryAttempts": int,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+GetAlternateContactResponseTypeDef = TypedDict(
+    "GetAlternateContactResponseTypeDef",
+    {
+        "AlternateContact": AlternateContactTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
